==> media_alias_display-1.0.5.tar.gz: media_alias_display/README.md <==
CONTENTS OF THIS FILE
---------------------

* Introduction
* Requirements
* Recommended modules
* Installation
* Configuration
* Maintainers

INTRODUCTION
------------

This module allows for direct viewing of a file with the URL alias.  Instead of viewing the media entity and all the
fields users can view a file (like a PDF) but instead of sites/default/files/name-of-file it will display the URL alias.

This is useful if a media object is referenced in multiple locations the media object can be updated with a new file
and reflected in all instances automatically.


REQUIREMENTS
------------

This module requires:

* PHP > 7.2CONTENTS OF THIS FILE
---------------------

* Introduction
* Requirements
* Recommended modules
* Installation
* Configuration
* Maintainers

INTRODUCTION
------------

This module allows for direct viewing of a file with the URL alias.  Instead of viewing the media entity and all the
fields users can view a file (like a PDF) but instead of sites/default/files/name-of-file it will display the URL alias.

This is useful if a media object is referenced in multiple locations the media object can be updated with a new file
and reflected in all instances automatically.


REQUIREMENTS
------------

This module requires:

* PHP > 7.2
* Drupal Core Media


Recommended modules
------------

* Pathauto (https://www.drupal.org/project/pathauto)
* Drupal Core Workflow

INSTALLATION
------------

Install as you would normally install a contributed Drupal module. Visit:
https://www.drupal.org/docs/extending-drupal/installing-drupal-modules
for further information.

TRICKS
------

* If you're viewing a file with an alias and need help finding the media object just append
  ?edit-media.  This will redirect you straight to the media edit page.

CONFIGURATION
-------------

Once the module is installed.

* Go to /admin/config/media/media-settings and verify "Standalone media URL" is checked.

MAINTAINERS
-----------

Current maintainers:
* Stephen Mustgrave (smustgrave) (https://www.drupal.org/u/smustgrave)

* Drupal Core Media


Recommended modules
------------

* Pathauto (https://www.drupal.org/project/pathauto)
* Drupal Core Workflow

INSTALLATION
------------

Install as you would normally install a contributed Drupal module. Visit:
https://www.drupal.org/docs/extending-drupal/installing-drupal-modules
for further information.


CONFIGURATION
-------------

Once the module is installed.

* Go to /admin/config/media/media-settings and verify "Standalone media URL" is checked.

MAINTAINERS
-----------

Current maintainers:
* Stephen Mustgrave (smustgrave) (https://www.drupal.org/u/smustgrave)

==> media_alias_display-1.0.7.tar.gz: media_alias_display/README.md <==
CONTENTS OF THIS FILE
---------------------

* Introduction
* Requirements
* Recommended modules
* Installation
* Configuration
* Maintainers

INTRODUCTION
------------

This module allows for direct viewing of a file with the URL alias.  Instead of viewing the media entity and all the
fields users can view a file (like a PDF) but instead of sites/default/files/name-of-file it will display the URL alias.

This is useful if a media object is referenced in multiple locations the media object can be updated with a new file
and reflected in all instances automatically.


REQUIREMENTS
------------

This module requires:

* PHP > 7.4

CONTENTS OF THIS FILE
---------------------

* Introduction
* Requirements
* Recommended modules
* Installation
* Configuration
* Maintainers

INTRODUCTION
------------

This module allows for direct viewing of a file with the URL alias.  Instead of viewing the media entity and all the
fields users can view a file (like a PDF) but instead of sites/default/files/name-of-file it will display the URL alias.

This is useful if a media object is referenced in multiple locations the media object can be updated with a new file
and reflected in all instances automatically.


REQUIREMENTS
------------

This module requires:

* PHP > 7.4
* Drupal Core Media


Recommended modules
------------

* Pathauto (https://www.drupal.org/project/pathauto)
* Drupal Core Workflow

INSTALLATION
------------

Install as you would normally install a contributed Drupal module. Visit:
https://www.drupal.org/docs/extending-drupal/installing-drupal-modules
for further information.

TRICKS
------

* If you're viewing a file with an alias and need help finding the media object just append
  `?edit-media` to the URL, this will redirect you straight to the media edit page.
* If you want the media file to be downloaded, you may append `?download` or `?dl` to the URL.

CONFIGURATION
-------------

Once the module is installed.

* Go to /admin/config/media/media-settings and verify "Standalone media URL" is checked.

MAINTAINERS
-----------

Current maintainers:
* Stephen Mustgrave (smustgrave) (https://www.drupal.org/u/smustgrave)

* Drupal Core Media


Recommended modules
------------

* Pathauto (https://www.drupal.org/project/pathauto)
* Drupal Core Workflow

INSTALLATION
------------

Install as you would normally install a contributed Drupal module. Visit:
https://www.drupal.org/docs/extending-drupal/installing-drupal-modules
for further information.


CONFIGURATION
-------------

Once the module is installed.

* Go to /admin/config/media/media-settings and verify "Standalone media URL" is checked.

MAINTAINERS
-----------

Current maintainers:
* Stephen Mustgrave (smustgrave) (https://www.drupal.org/u/smustgrave)
